# Toika Web Server

Software that allows you to control a Toika dobby loom from any modern web browser, e.g. on a phone or tablet.

For more information, read the [main documentation](https://r-owen.github.io/base_loom_server/).

You must decide whether the control direction (weave/unweave) using the REVERSE button on the dobby head or the direction button in the browser display.
Read more about this under [Weave Direction](https://r-owen.github.io/base_loom_server/weaving/#weave-direction).
Make your choice in the Settings panel.

## Links

toika_loom_server depends on [base_loom_server](https://pypi.org/project/base-loom-server/), which does most of the work and has the [main documentation](https://r-owen.github.io/base_loom_server/).

toka_loom_server is served at [PyPI](https://pypi.org/project/toika-loom-server/).
The source code is at [github](https://r-owen.github.io/toika_loom_server/).
I suggest filing bug reports using [base_loom_server's issue tracker](https://github.com/r-owen/toika_loom_server/issues).

## Acknowledgements

Thanks to Jukka Yrjölä and Jarkko Yrjölä from Toika for providing the API and helpful clarification.

Thanks to WillowGoose ([willowlovestoweave](https://www.instagram.com/willowlovestoweave/) on Instagram) for patiently testing this software and proving valuable feedback.
